- Mathieu Blondel
- Joris Van den Bossche
- Matthieu Brucher
- Lars Buitinck
- David Cournapeau
- Noel Dawe
- Vincent Dubourg
- Edouard Duchesnay
- Alexander Fabisch
- Virgile Fritsch
- Satrajit Ghosh
- Angel Soler Gollonet
- Chris Gorgolewski
- Jaques Grobler
- Yaroslav Halchenko
- Brian Holt
- Arnaud Joly
- Thouis (Ray) Jones
- Kyle Kastner
- Manoj Kumar
- Robert Layton
- Wei Li
- Paolo Losi
- Gilles Louppe
- Jan Hendrik Metzen
- Vincent Michel
- Jarrod Millman
- Vlad Niculae
- Alexandre Passos
- Fabian Pedregosa
- Peter Prettenhofer
- Hanmin Qin
- (Venkat) Raghav, Rajagopalan
- Jacob Schreiber
- 杜世橋 Du Shiqiao
- Bertrand Thirion
- Tom Dupré la Tour
- Jake Vanderplas
- Nelle Varoquaux
- David Warde-Farley
- Ron Weiss
- Roman Yurchak